# coolprint

coolprint is a library that prints coolly.

### Installation

```
pip install coolprint
```

### Usage
```
from coolprint import coolprint

coolprint("Mission Impossible...?", 0.05)
# or 
coolprint("This is so cool!")

```